# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import campaign_draft_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__draft__pb2
from google.ads.google_ads.v2.proto.services import campaign_draft_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2


class CampaignDraftServiceStub(object):
  """Proto file describing the Campaign Draft service.

  Service to manage campaign drafts.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCampaignDraft = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignDraftService/GetCampaignDraft',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2.GetCampaignDraftRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__draft__pb2.CampaignDraft.FromString,
        )
    self.MutateCampaignDrafts = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignDraftService/MutateCampaignDrafts',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2.MutateCampaignDraftsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2.MutateCampaignDraftsResponse.FromString,
        )
    self.PromoteCampaignDraft = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignDraftService/PromoteCampaignDraft',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2.PromoteCampaignDraftRequest.SerializeToString,
        response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
    self.ListCampaignDraftAsyncErrors = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignDraftService/ListCampaignDraftAsyncErrors',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2.ListCampaignDraftAsyncErrorsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2.ListCampaignDraftAsyncErrorsResponse.FromString,
        )


class CampaignDraftServiceServicer(object):
  """Proto file describing the Campaign Draft service.

  Service to manage campaign drafts.
  """

  def GetCampaignDraft(self, request, context):
    """Returns the requested campaign draft in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCampaignDrafts(self, request, context):
    """Creates, updates, or removes campaign drafts. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PromoteCampaignDraft(self, request, context):
    """Promotes the changes in a draft back to the base campaign.

    This method returns a Long Running Operation (LRO) indicating if the
    Promote is done. Use [Operations.GetOperation] to poll the LRO until it
    is done. Only a done status is returned in the response. See the status
    in the Campaign Draft resource to determine if the promotion was
    successful. If the LRO failed, use
    [CampaignDraftService.ListCampaignDraftAsyncErrors][google.ads.googleads.v2.services.CampaignDraftService.ListCampaignDraftAsyncErrors] to view the list of
    error reasons.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListCampaignDraftAsyncErrors(self, request, context):
    """Returns all errors that occurred during CampaignDraft promote. Throws an
    error if called before campaign draft is promoted.
    Supports standard list paging.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CampaignDraftServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCampaignDraft': grpc.unary_unary_rpc_method_handler(
          servicer.GetCampaignDraft,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2.GetCampaignDraftRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__draft__pb2.CampaignDraft.SerializeToString,
      ),
      'MutateCampaignDrafts': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCampaignDrafts,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2.MutateCampaignDraftsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2.MutateCampaignDraftsResponse.SerializeToString,
      ),
      'PromoteCampaignDraft': grpc.unary_unary_rpc_method_handler(
          servicer.PromoteCampaignDraft,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2.PromoteCampaignDraftRequest.FromString,
          response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
      ),
      'ListCampaignDraftAsyncErrors': grpc.unary_unary_rpc_method_handler(
          servicer.ListCampaignDraftAsyncErrors,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2.ListCampaignDraftAsyncErrorsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__draft__service__pb2.ListCampaignDraftAsyncErrorsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.CampaignDraftService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/ad_group_criterion.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import criteria_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2
from google.ads.google_ads.v2.proto.common import custom_parameter_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2
from google.ads.google_ads.v2.proto.enums import ad_group_criterion_approval_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__group__criterion__approval__status__pb2
from google.ads.google_ads.v2.proto.enums import ad_group_criterion_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__group__criterion__status__pb2
from google.ads.google_ads.v2.proto.enums import bidding_source_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bidding__source__pb2
from google.ads.google_ads.v2.proto.enums import criterion_system_serving_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_criterion__system__serving__status__pb2
from google.ads.google_ads.v2.proto.enums import criterion_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_criterion__type__pb2
from google.ads.google_ads.v2.proto.enums import quality_score_bucket_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_quality__score__bucket__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/ad_group_criterion.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\025AdGroupCriterionProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n@google/ads/googleads_v2/proto/resources/ad_group_criterion.proto\x12!google.ads.googleads.v2.resources\x1a\x33google/ads/googleads_v2/proto/common/criteria.proto\x1a;google/ads/googleads_v2/proto/common/custom_parameter.proto\x1aLgoogle/ads/googleads_v2/proto/enums/ad_group_criterion_approval_status.proto\x1a\x43google/ads/googleads_v2/proto/enums/ad_group_criterion_status.proto\x1a\x38google/ads/googleads_v2/proto/enums/bidding_source.proto\x1aIgoogle/ads/googleads_v2/proto/enums/criterion_system_serving_status.proto\x1a\x38google/ads/googleads_v2/proto/enums/criterion_type.proto\x1a>google/ads/googleads_v2/proto/enums/quality_score_bucket.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\x91 \n\x10\x41\x64GroupCriterion\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x31\n\x0c\x63riterion_id\x18\x1a \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12`\n\x06status\x18\x03 \x01(\x0e\x32P.google.ads.googleads.v2.enums.AdGroupCriterionStatusEnum.AdGroupCriterionStatus\x12U\n\x0cquality_info\x18\x04 \x01(\x0b\x32?.google.ads.googleads.v2.resources.AdGroupCriterion.QualityInfo\x12.\n\x08\x61\x64_group\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12L\n\x04type\x18\x19 \x01(\x0e\x32>.google.ads.googleads.v2.enums.CriterionTypeEnum.CriterionType\x12,\n\x08negative\x18\x1f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12{\n\x15system_serving_status\x18\x34 \x01(\x0e\x32\\.google.ads.googleads.v2.enums.CriterionSystemServingStatusEnum.CriterionSystemServingStatus\x12y\n\x0f\x61pproval_status\x18\x35 \x01(\x0e\x32`.google.ads.googleads.v2.enums.AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus\x12\x32\n\x0c\x62id_modifier\x18, \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x33\n\x0e\x63pc_bid_micros\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0e\x63pm_bid_micros\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0e\x63pv_bid_micros\x18\x18 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16percent_cpc_bid_micros\x18! \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x18\x65\x66\x66\x65\x63tive_cpc_bid_micros\x18\x12 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x18\x65\x66\x66\x65\x63tive_cpm_bid_micros\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x18\x65\x66\x66\x65\x63tive_cpv_bid_micros\x18\x14 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x45\n effective_percent_cpc_bid_micros\x18\" \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12`\n\x18\x65\x66\x66\x65\x63tive_cpc_bid_source\x18\x15 \x01(\x0e\x32>.google.ads.googleads.v2.enums.BiddingSourceEnum.BiddingSource\x12`\n\x18\x65\x66\x66\x65\x63tive_cpm_bid_source\x18\x16 \x01(\x0e\x32>.google.ads.googleads.v2.enums.BiddingSourceEnum.BiddingSource\x12`\n\x18\x65\x66\x66\x65\x63tive_cpv_bid_source\x18\x17 \x01(\x0e\x32>.google.ads.googleads.v2.enums.BiddingSourceEnum.BiddingSource\x12h\n effective_percent_cpc_bid_source\x18# \x01(\x0e\x32>.google.ads.googleads.v2.enums.BiddingSourceEnum.BiddingSource\x12\x61\n\x12position_estimates\x18\n \x01(\x0b\x32\x45.google.ads.googleads.v2.resources.AdGroupCriterion.PositionEstimates\x12\x30\n\nfinal_urls\x18\x0b \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11\x66inal_mobile_urls\x18\x33 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10\x66inal_url_suffix\x18\x32 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15tracking_url_template\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12N\n\x15url_custom_parameters\x18\x0e \x03(\x0b\x32/.google.ads.googleads.v2.common.CustomParameter\x12>\n\x07keyword\x18\x1b \x01(\x0b\x32+.google.ads.googleads.v2.common.KeywordInfoH\x00\x12\x42\n\tplacement\x18\x1c \x01(\x0b\x32-.google.ads.googleads.v2.common.PlacementInfoH\x00\x12T\n\x13mobile_app_category\x18\x1d \x01(\x0b\x32\x35.google.ads.googleads.v2.common.MobileAppCategoryInfoH\x00\x12S\n\x12mobile_application\x18\x1e \x01(\x0b\x32\x35.google.ads.googleads.v2.common.MobileApplicationInfoH\x00\x12I\n\rlisting_group\x18  \x01(\x0b\x32\x30.google.ads.googleads.v2.common.ListingGroupInfoH\x00\x12\x41\n\tage_range\x18$ \x01(\x0b\x32,.google.ads.googleads.v2.common.AgeRangeInfoH\x00\x12<\n\x06gender\x18% \x01(\x0b\x32*.google.ads.googleads.v2.common.GenderInfoH\x00\x12G\n\x0cincome_range\x18& \x01(\x0b\x32/.google.ads.googleads.v2.common.IncomeRangeInfoH\x00\x12M\n\x0fparental_status\x18\' \x01(\x0b\x32\x32.google.ads.googleads.v2.common.ParentalStatusInfoH\x00\x12\x41\n\tuser_list\x18* \x01(\x0b\x32,.google.ads.googleads.v2.common.UserListInfoH\x00\x12I\n\ryoutube_video\x18( \x01(\x0b\x32\x30.google.ads.googleads.v2.common.YouTubeVideoInfoH\x00\x12M\n\x0fyoutube_channel\x18) \x01(\x0b\x32\x32.google.ads.googleads.v2.common.YouTubeChannelInfoH\x00\x12:\n\x05topic\x18+ \x01(\x0b\x32).google.ads.googleads.v2.common.TopicInfoH\x00\x12I\n\ruser_interest\x18- \x01(\x0b\x32\x30.google.ads.googleads.v2.common.UserInterestInfoH\x00\x12>\n\x07webpage\x18. \x01(\x0b\x32+.google.ads.googleads.v2.common.WebpageInfoH\x00\x12P\n\x11\x61pp_payment_model\x18/ \x01(\x0b\x32\x33.google.ads.googleads.v2.common.AppPaymentModelInfoH\x00\x12M\n\x0f\x63ustom_affinity\x18\x30 \x01(\x0b\x32\x32.google.ads.googleads.v2.common.CustomAffinityInfoH\x00\x12I\n\rcustom_intent\x18\x31 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.CustomIntentInfoH\x00\x1a\xff\x02\n\x0bQualityInfo\x12\x32\n\rquality_score\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12h\n\x16\x63reative_quality_score\x18\x02 \x01(\x0e\x32H.google.ads.googleads.v2.enums.QualityScoreBucketEnum.QualityScoreBucket\x12j\n\x18post_click_quality_score\x18\x03 \x01(\x0e\x32H.google.ads.googleads.v2.enums.QualityScoreBucketEnum.QualityScoreBucket\x12\x66\n\x14search_predicted_ctr\x18\x04 \x01(\x0e\x32H.google.ads.googleads.v2.enums.QualityScoreBucketEnum.QualityScoreBucket\x1a\xec\x02\n\x11PositionEstimates\x12:\n\x15\x66irst_page_cpc_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19\x66irst_position_cpc_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16top_of_page_cpc_micros\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12O\n*estimated_add_clicks_at_first_position_cpc\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12M\n(estimated_add_cost_at_first_position_cpc\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\n\tcriterionB\x82\x02\n%com.google.ads.googleads.v2.resourcesB\x15\x41\x64GroupCriterionProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__group__criterion__approval__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__group__criterion__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bidding__source__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_criterion__system__serving__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_criterion__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_quality__score__bucket__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_ADGROUPCRITERION_QUALITYINFO = _descriptor.Descriptor(
  name='QualityInfo',
  full_name='google.ads.googleads.v2.resources.AdGroupCriterion.QualityInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quality_score', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.QualityInfo.quality_score', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creative_quality_score', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.QualityInfo.creative_quality_score', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='post_click_quality_score', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.QualityInfo.post_click_quality_score', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_predicted_ctr', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.QualityInfo.search_predicted_ctr', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4032,
  serialized_end=4415,
)

_ADGROUPCRITERION_POSITIONESTIMATES = _descriptor.Descriptor(
  name='PositionEstimates',
  full_name='google.ads.googleads.v2.resources.AdGroupCriterion.PositionEstimates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='first_page_cpc_micros', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.PositionEstimates.first_page_cpc_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_position_cpc_micros', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.PositionEstimates.first_position_cpc_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top_of_page_cpc_micros', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.PositionEstimates.top_of_page_cpc_micros', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='estimated_add_clicks_at_first_position_cpc', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.PositionEstimates.estimated_add_clicks_at_first_position_cpc', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='estimated_add_cost_at_first_position_cpc', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.PositionEstimates.estimated_add_cost_at_first_position_cpc', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4418,
  serialized_end=4782,
)

_ADGROUPCRITERION = _descriptor.Descriptor(
  name='AdGroupCriterion',
  full_name='google.ads.googleads.v2.resources.AdGroupCriterion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='criterion_id', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.criterion_id', index=1,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality_info', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.quality_info', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.ad_group', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.type', index=5,
      number=25, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='negative', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.negative', index=6,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='system_serving_status', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.system_serving_status', index=7,
      number=52, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approval_status', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.approval_status', index=8,
      number=53, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bid_modifier', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.bid_modifier', index=9,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpc_bid_micros', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.cpc_bid_micros', index=10,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpm_bid_micros', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.cpm_bid_micros', index=11,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpv_bid_micros', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.cpv_bid_micros', index=12,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percent_cpc_bid_micros', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.percent_cpc_bid_micros', index=13,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effective_cpc_bid_micros', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.effective_cpc_bid_micros', index=14,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effective_cpm_bid_micros', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.effective_cpm_bid_micros', index=15,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effective_cpv_bid_micros', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.effective_cpv_bid_micros', index=16,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effective_percent_cpc_bid_micros', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.effective_percent_cpc_bid_micros', index=17,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effective_cpc_bid_source', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.effective_cpc_bid_source', index=18,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effective_cpm_bid_source', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.effective_cpm_bid_source', index=19,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effective_cpv_bid_source', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.effective_cpv_bid_source', index=20,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effective_percent_cpc_bid_source', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.effective_percent_cpc_bid_source', index=21,
      number=35, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_estimates', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.position_estimates', index=22,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_urls', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.final_urls', index=23,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_mobile_urls', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.final_mobile_urls', index=24,
      number=51, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_url_suffix', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.final_url_suffix', index=25,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracking_url_template', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.tracking_url_template', index=26,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_custom_parameters', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.url_custom_parameters', index=27,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.keyword', index=28,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placement', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.placement', index=29,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile_app_category', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.mobile_app_category', index=30,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile_application', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.mobile_application', index=31,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='listing_group', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.listing_group', index=32,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='age_range', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.age_range', index=33,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gender', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.gender', index=34,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='income_range', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.income_range', index=35,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parental_status', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.parental_status', index=36,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_list', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.user_list', index=37,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='youtube_video', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.youtube_video', index=38,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='youtube_channel', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.youtube_channel', index=39,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='topic', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.topic', index=40,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_interest', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.user_interest', index=41,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='webpage', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.webpage', index=42,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_payment_model', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.app_payment_model', index=43,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_affinity', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.custom_affinity', index=44,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_intent', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.custom_intent', index=45,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ADGROUPCRITERION_QUALITYINFO, _ADGROUPCRITERION_POSITIONESTIMATES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='criterion', full_name='google.ads.googleads.v2.resources.AdGroupCriterion.criterion',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=682,
  serialized_end=4795,
)

_ADGROUPCRITERION_QUALITYINFO.fields_by_name['quality_score'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_ADGROUPCRITERION_QUALITYINFO.fields_by_name['creative_quality_score'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_quality__score__bucket__pb2._QUALITYSCOREBUCKETENUM_QUALITYSCOREBUCKET
_ADGROUPCRITERION_QUALITYINFO.fields_by_name['post_click_quality_score'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_quality__score__bucket__pb2._QUALITYSCOREBUCKETENUM_QUALITYSCOREBUCKET
_ADGROUPCRITERION_QUALITYINFO.fields_by_name['search_predicted_ctr'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_quality__score__bucket__pb2._QUALITYSCOREBUCKETENUM_QUALITYSCOREBUCKET
_ADGROUPCRITERION_QUALITYINFO.containing_type = _ADGROUPCRITERION
_ADGROUPCRITERION_POSITIONESTIMATES.fields_by_name['first_page_cpc_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUPCRITERION_POSITIONESTIMATES.fields_by_name['first_position_cpc_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUPCRITERION_POSITIONESTIMATES.fields_by_name['top_of_page_cpc_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUPCRITERION_POSITIONESTIMATES.fields_by_name['estimated_add_clicks_at_first_position_cpc'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUPCRITERION_POSITIONESTIMATES.fields_by_name['estimated_add_cost_at_first_position_cpc'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUPCRITERION_POSITIONESTIMATES.containing_type = _ADGROUPCRITERION
_ADGROUPCRITERION.fields_by_name['criterion_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUPCRITERION.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__group__criterion__status__pb2._ADGROUPCRITERIONSTATUSENUM_ADGROUPCRITERIONSTATUS
_ADGROUPCRITERION.fields_by_name['quality_info'].message_type = _ADGROUPCRITERION_QUALITYINFO
_ADGROUPCRITERION.fields_by_name['ad_group'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADGROUPCRITERION.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_criterion__type__pb2._CRITERIONTYPEENUM_CRITERIONTYPE
_ADGROUPCRITERION.fields_by_name['negative'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_ADGROUPCRITERION.fields_by_name['system_serving_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_criterion__system__serving__status__pb2._CRITERIONSYSTEMSERVINGSTATUSENUM_CRITERIONSYSTEMSERVINGSTATUS
_ADGROUPCRITERION.fields_by_name['approval_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__group__criterion__approval__status__pb2._ADGROUPCRITERIONAPPROVALSTATUSENUM_ADGROUPCRITERIONAPPROVALSTATUS
_ADGROUPCRITERION.fields_by_name['bid_modifier'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_ADGROUPCRITERION.fields_by_name['cpc_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUPCRITERION.fields_by_name['cpm_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUPCRITERION.fields_by_name['cpv_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUPCRITERION.fields_by_name['percent_cpc_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUPCRITERION.fields_by_name['effective_cpc_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUPCRITERION.fields_by_name['effective_cpm_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUPCRITERION.fields_by_name['effective_cpv_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUPCRITERION.fields_by_name['effective_percent_cpc_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADGROUPCRITERION.fields_by_name['effective_cpc_bid_source'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bidding__source__pb2._BIDDINGSOURCEENUM_BIDDINGSOURCE
_ADGROUPCRITERION.fields_by_name['effective_cpm_bid_source'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bidding__source__pb2._BIDDINGSOURCEENUM_BIDDINGSOURCE
_ADGROUPCRITERION.fields_by_name['effective_cpv_bid_source'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bidding__source__pb2._BIDDINGSOURCEENUM_BIDDINGSOURCE
_ADGROUPCRITERION.fields_by_name['effective_percent_cpc_bid_source'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bidding__source__pb2._BIDDINGSOURCEENUM_BIDDINGSOURCE
_ADGROUPCRITERION.fields_by_name['position_estimates'].message_type = _ADGROUPCRITERION_POSITIONESTIMATES
_ADGROUPCRITERION.fields_by_name['final_urls'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADGROUPCRITERION.fields_by_name['final_mobile_urls'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADGROUPCRITERION.fields_by_name['final_url_suffix'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADGROUPCRITERION.fields_by_name['tracking_url_template'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADGROUPCRITERION.fields_by_name['url_custom_parameters'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2._CUSTOMPARAMETER
_ADGROUPCRITERION.fields_by_name['keyword'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._KEYWORDINFO
_ADGROUPCRITERION.fields_by_name['placement'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._PLACEMENTINFO
_ADGROUPCRITERION.fields_by_name['mobile_app_category'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._MOBILEAPPCATEGORYINFO
_ADGROUPCRITERION.fields_by_name['mobile_application'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._MOBILEAPPLICATIONINFO
_ADGROUPCRITERION.fields_by_name['listing_group'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._LISTINGGROUPINFO
_ADGROUPCRITERION.fields_by_name['age_range'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._AGERANGEINFO
_ADGROUPCRITERION.fields_by_name['gender'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._GENDERINFO
_ADGROUPCRITERION.fields_by_name['income_range'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._INCOMERANGEINFO
_ADGROUPCRITERION.fields_by_name['parental_status'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._PARENTALSTATUSINFO
_ADGROUPCRITERION.fields_by_name['user_list'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._USERLISTINFO
_ADGROUPCRITERION.fields_by_name['youtube_video'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._YOUTUBEVIDEOINFO
_ADGROUPCRITERION.fields_by_name['youtube_channel'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._YOUTUBECHANNELINFO
_ADGROUPCRITERION.fields_by_name['topic'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._TOPICINFO
_ADGROUPCRITERION.fields_by_name['user_interest'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._USERINTERESTINFO
_ADGROUPCRITERION.fields_by_name['webpage'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._WEBPAGEINFO
_ADGROUPCRITERION.fields_by_name['app_payment_model'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._APPPAYMENTMODELINFO
_ADGROUPCRITERION.fields_by_name['custom_affinity'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._CUSTOMAFFINITYINFO
_ADGROUPCRITERION.fields_by_name['custom_intent'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._CUSTOMINTENTINFO
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['keyword'])
_ADGROUPCRITERION.fields_by_name['keyword'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['placement'])
_ADGROUPCRITERION.fields_by_name['placement'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['mobile_app_category'])
_ADGROUPCRITERION.fields_by_name['mobile_app_category'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['mobile_application'])
_ADGROUPCRITERION.fields_by_name['mobile_application'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['listing_group'])
_ADGROUPCRITERION.fields_by_name['listing_group'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['age_range'])
_ADGROUPCRITERION.fields_by_name['age_range'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['gender'])
_ADGROUPCRITERION.fields_by_name['gender'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['income_range'])
_ADGROUPCRITERION.fields_by_name['income_range'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['parental_status'])
_ADGROUPCRITERION.fields_by_name['parental_status'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['user_list'])
_ADGROUPCRITERION.fields_by_name['user_list'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['youtube_video'])
_ADGROUPCRITERION.fields_by_name['youtube_video'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['youtube_channel'])
_ADGROUPCRITERION.fields_by_name['youtube_channel'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['topic'])
_ADGROUPCRITERION.fields_by_name['topic'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['user_interest'])
_ADGROUPCRITERION.fields_by_name['user_interest'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['webpage'])
_ADGROUPCRITERION.fields_by_name['webpage'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['app_payment_model'])
_ADGROUPCRITERION.fields_by_name['app_payment_model'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['custom_affinity'])
_ADGROUPCRITERION.fields_by_name['custom_affinity'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
_ADGROUPCRITERION.oneofs_by_name['criterion'].fields.append(
  _ADGROUPCRITERION.fields_by_name['custom_intent'])
_ADGROUPCRITERION.fields_by_name['custom_intent'].containing_oneof = _ADGROUPCRITERION.oneofs_by_name['criterion']
DESCRIPTOR.message_types_by_name['AdGroupCriterion'] = _ADGROUPCRITERION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdGroupCriterion = _reflection.GeneratedProtocolMessageType('AdGroupCriterion', (_message.Message,), dict(

  QualityInfo = _reflection.GeneratedProtocolMessageType('QualityInfo', (_message.Message,), dict(
    DESCRIPTOR = _ADGROUPCRITERION_QUALITYINFO,
    __module__ = 'google.ads.googleads_v2.proto.resources.ad_group_criterion_pb2'
    ,
    __doc__ = """A container for ad group criterion quality information.
    
    
    Attributes:
        quality_score:
            The quality score.  This field may not be populated if Google
            does not have enough information to determine a value.
        creative_quality_score:
            The performance of the ad compared to other advertisers.
        post_click_quality_score:
            The quality score of the landing page.
        search_predicted_ctr:
            The click-through rate compared to that of other advertisers.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.AdGroupCriterion.QualityInfo)
    ))
  ,

  PositionEstimates = _reflection.GeneratedProtocolMessageType('PositionEstimates', (_message.Message,), dict(
    DESCRIPTOR = _ADGROUPCRITERION_POSITIONESTIMATES,
    __module__ = 'google.ads.googleads_v2.proto.resources.ad_group_criterion_pb2'
    ,
    __doc__ = """Estimates for criterion bids at various positions.
    
    
    Attributes:
        first_page_cpc_micros:
            The estimate of the CPC bid required for ad to be shown on
            first page of search results.
        first_position_cpc_micros:
            The estimate of the CPC bid required for ad to be displayed in
            first position, at the top of the first page of search
            results.
        top_of_page_cpc_micros:
            The estimate of the CPC bid required for ad to be displayed at
            the top of the first page of search results.
        estimated_add_clicks_at_first_position_cpc:
            Estimate of how many clicks per week you might get by changing
            your keyword bid to the value in first\_position\_cpc\_micros.
        estimated_add_cost_at_first_position_cpc:
            Estimate of how your cost per week might change when changing
            your keyword bid to the value in first\_position\_cpc\_micros.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.AdGroupCriterion.PositionEstimates)
    ))
  ,
  DESCRIPTOR = _ADGROUPCRITERION,
  __module__ = 'google.ads.googleads_v2.proto.resources.ad_group_criterion_pb2'
  ,
  __doc__ = """An ad group criterion.
  
  
  Attributes:
      resource_name:
          The resource name of the ad group criterion. Ad group
          criterion resource names have the form:  ``customers/{customer
          _id}/adGroupCriteria/{ad_group_id}~{criterion_id}``
      criterion_id:
          The ID of the criterion.  This field is ignored for mutates.
      status:
          The status of the criterion.
      quality_info:
          Information regarding the quality of the criterion.
      ad_group:
          The ad group to which the criterion belongs.
      type:
          The type of the criterion.
      negative:
          Whether to target (``false``) or exclude (``true``) the
          criterion.  This field is immutable. To switch a criterion
          from positive to negative, remove then re-add it.
      system_serving_status:
          Serving status of the criterion.
      approval_status:
          Approval status of the criterion.
      bid_modifier:
          The modifier for the bid when the criterion matches. The
          modifier must be in the range: 0.1 - 10.0. Most targetable
          criteria types support modifiers.
      cpc_bid_micros:
          The CPC (cost-per-click) bid.
      cpm_bid_micros:
          The CPM (cost-per-thousand viewable impressions) bid.
      cpv_bid_micros:
          The CPV (cost-per-view) bid.
      percent_cpc_bid_micros:
          The CPC bid amount, expressed as a fraction of the advertised
          price for some good or service. The valid range for the
          fraction is [0,1) and the value stored here is 1,000,000 \*
          [fraction].
      effective_cpc_bid_micros:
          The effective CPC (cost-per-click) bid.
      effective_cpm_bid_micros:
          The effective CPM (cost-per-thousand viewable impressions)
          bid.
      effective_cpv_bid_micros:
          The effective CPV (cost-per-view) bid.
      effective_percent_cpc_bid_micros:
          The effective Percent CPC bid amount.
      effective_cpc_bid_source:
          Source of the effective CPC bid.
      effective_cpm_bid_source:
          Source of the effective CPM bid.
      effective_cpv_bid_source:
          Source of the effective CPV bid.
      effective_percent_cpc_bid_source:
          Source of the effective Percent CPC bid.
      position_estimates:
          Estimates for criterion bids at various positions.
      final_urls:
          The list of possible final URLs after all cross-domain
          redirects for the ad.
      final_mobile_urls:
          The list of possible final mobile URLs after all cross-domain
          redirects.
      final_url_suffix:
          URL template for appending params to final URL.
      tracking_url_template:
          The URL template for constructing a tracking URL.
      url_custom_parameters:
          The list of mappings used to substitute custom parameter tags
          in a ``tracking_url_template``, ``final_urls``, or
          ``mobile_final_urls``.
      criterion:
          The ad group criterion.  Exactly one must be set.
      keyword:
          Keyword.
      placement:
          Placement.
      mobile_app_category:
          Mobile app category.
      mobile_application:
          Mobile application.
      listing_group:
          Listing group.
      age_range:
          Age range.
      gender:
          Gender.
      income_range:
          Income range.
      parental_status:
          Parental status.
      user_list:
          User List.
      youtube_video:
          YouTube Video.
      youtube_channel:
          YouTube Channel.
      topic:
          Topic.
      user_interest:
          User Interest.
      webpage:
          Webpage
      app_payment_model:
          App Payment Model.
      custom_affinity:
          Custom Affinity.
      custom_intent:
          Custom Intent.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.AdGroupCriterion)
  ))
_sym_db.RegisterMessage(AdGroupCriterion)
_sym_db.RegisterMessage(AdGroupCriterion.QualityInfo)
_sym_db.RegisterMessage(AdGroupCriterion.PositionEstimates)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/image_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/image_error.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\017ImageErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\n6google/ads/googleads_v2/proto/errors/image_error.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x1cgoogle/api/annotations.proto\"\x8a\x08\n\x0eImageErrorEnum\"\xf7\x07\n\nImageError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x11\n\rINVALID_IMAGE\x10\x02\x12\x11\n\rSTORAGE_ERROR\x10\x03\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x04\x12\x13\n\x0fUNEXPECTED_SIZE\x10\x05\x12\x18\n\x14\x41NIMATED_NOT_ALLOWED\x10\x06\x12\x16\n\x12\x41NIMATION_TOO_LONG\x10\x07\x12\x10\n\x0cSERVER_ERROR\x10\x08\x12\x19\n\x15\x43MYK_JPEG_NOT_ALLOWED\x10\t\x12\x15\n\x11\x46LASH_NOT_ALLOWED\x10\n\x12\x1a\n\x16\x46LASH_WITHOUT_CLICKTAG\x10\x0b\x12&\n\"FLASH_ERROR_AFTER_FIXING_CLICK_TAG\x10\x0c\x12\x1a\n\x16\x41NIMATED_VISUAL_EFFECT\x10\r\x12\x0f\n\x0b\x46LASH_ERROR\x10\x0e\x12\x12\n\x0eLAYOUT_PROBLEM\x10\x0f\x12\x1e\n\x1aPROBLEM_READING_IMAGE_FILE\x10\x10\x12\x17\n\x13\x45RROR_STORING_IMAGE\x10\x11\x12\x1c\n\x18\x41SPECT_RATIO_NOT_ALLOWED\x10\x12\x12\x1d\n\x19\x46LASH_HAS_NETWORK_OBJECTS\x10\x13\x12\x1d\n\x19\x46LASH_HAS_NETWORK_METHODS\x10\x14\x12\x11\n\rFLASH_HAS_URL\x10\x15\x12\x1c\n\x18\x46LASH_HAS_MOUSE_TRACKING\x10\x16\x12\x18\n\x14\x46LASH_HAS_RANDOM_NUM\x10\x17\x12\x16\n\x12\x46LASH_SELF_TARGETS\x10\x18\x12\x1b\n\x17\x46LASH_BAD_GETURL_TARGET\x10\x19\x12\x1f\n\x1b\x46LASH_VERSION_NOT_SUPPORTED\x10\x1a\x12&\n\"FLASH_WITHOUT_HARD_CODED_CLICK_URL\x10\x1b\x12\x16\n\x12INVALID_FLASH_FILE\x10\x1c\x12$\n FAILED_TO_FIX_CLICK_TAG_IN_FLASH\x10\x1d\x12$\n FLASH_ACCESSES_NETWORK_RESOURCES\x10\x1e\x12\x1a\n\x16\x46LASH_EXTERNAL_JS_CALL\x10\x1f\x12\x1a\n\x16\x46LASH_EXTERNAL_FS_CALL\x10 \x12\x12\n\x0e\x46ILE_TOO_LARGE\x10!\x12\x18\n\x14IMAGE_DATA_TOO_LARGE\x10\"\x12\x1a\n\x16IMAGE_PROCESSING_ERROR\x10#\x12\x13\n\x0fIMAGE_TOO_SMALL\x10$\x12\x11\n\rINVALID_INPUT\x10%\x12\x18\n\x14PROBLEM_READING_FILE\x10&B\xea\x01\n\"com.google.ads.googleads.v2.errorsB\x0fImageErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_IMAGEERRORENUM_IMAGEERROR = _descriptor.EnumDescriptor(
  name='ImageError',
  full_name='google.ads.googleads.v2.errors.ImageErrorEnum.ImageError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_IMAGE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STORAGE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNEXPECTED_SIZE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANIMATED_NOT_ALLOWED', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANIMATION_TOO_LONG', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVER_ERROR', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CMYK_JPEG_NOT_ALLOWED', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_NOT_ALLOWED', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_WITHOUT_CLICKTAG', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_ERROR_AFTER_FIXING_CLICK_TAG', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANIMATED_VISUAL_EFFECT', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_ERROR', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LAYOUT_PROBLEM', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROBLEM_READING_IMAGE_FILE', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_STORING_IMAGE', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASPECT_RATIO_NOT_ALLOWED', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_HAS_NETWORK_OBJECTS', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_HAS_NETWORK_METHODS', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_HAS_URL', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_HAS_MOUSE_TRACKING', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_HAS_RANDOM_NUM', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_SELF_TARGETS', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_BAD_GETURL_TARGET', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_VERSION_NOT_SUPPORTED', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_WITHOUT_HARD_CODED_CLICK_URL', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FLASH_FILE', index=28, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_TO_FIX_CLICK_TAG_IN_FLASH', index=29, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_ACCESSES_NETWORK_RESOURCES', index=30, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_EXTERNAL_JS_CALL', index=31, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLASH_EXTERNAL_FS_CALL', index=32, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FILE_TOO_LARGE', index=33, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_DATA_TOO_LARGE', index=34, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_PROCESSING_ERROR', index=35, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_TOO_SMALL', index=36, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_INPUT', index=37, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROBLEM_READING_FILE', index=38, number=38,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=140,
  serialized_end=1155,
)
_sym_db.RegisterEnumDescriptor(_IMAGEERRORENUM_IMAGEERROR)


_IMAGEERRORENUM = _descriptor.Descriptor(
  name='ImageErrorEnum',
  full_name='google.ads.googleads.v2.errors.ImageErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IMAGEERRORENUM_IMAGEERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=1155,
)

_IMAGEERRORENUM_IMAGEERROR.containing_type = _IMAGEERRORENUM
DESCRIPTOR.message_types_by_name['ImageErrorEnum'] = _IMAGEERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ImageErrorEnum = _reflection.GeneratedProtocolMessageType('ImageErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEERRORENUM,
  __module__ = 'google.ads.googleads_v2.proto.errors.image_error_pb2'
  ,
  __doc__ = """Container for enum describing possible image errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.ImageErrorEnum)
  ))
_sym_db.RegisterMessage(ImageErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/click_type.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/click_type.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB\016ClickTypeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\n4google/ads/googleads_v1/proto/enums/click_type.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\xa6\x0c\n\rClickTypeEnum\"\x94\x0c\n\tClickType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x10\n\x0c\x41PP_DEEPLINK\x10\x02\x12\x0f\n\x0b\x42READCRUMBS\x10\x03\x12\x12\n\x0e\x42ROADBAND_PLAN\x10\x04\x12\x11\n\rCALL_TRACKING\x10\x05\x12\t\n\x05\x43\x41LLS\x10\x06\x12\x1a\n\x16\x43LICK_ON_ENGAGEMENT_AD\x10\x07\x12\x12\n\x0eGET_DIRECTIONS\x10\x08\x12\x16\n\x12LOCATION_EXPANSION\x10\t\x12\x18\n\x14LOCATION_FORMAT_CALL\x10\n\x12\x1e\n\x1aLOCATION_FORMAT_DIRECTIONS\x10\x0b\x12\x19\n\x15LOCATION_FORMAT_IMAGE\x10\x0c\x12 \n\x1cLOCATION_FORMAT_LANDING_PAGE\x10\r\x12\x17\n\x13LOCATION_FORMAT_MAP\x10\x0e\x12\x1e\n\x1aLOCATION_FORMAT_STORE_INFO\x10\x0f\x12\x18\n\x14LOCATION_FORMAT_TEXT\x10\x10\x12\x18\n\x14MOBILE_CALL_TRACKING\x10\x11\x12\x10\n\x0cOFFER_PRINTS\x10\x12\x12\t\n\x05OTHER\x10\x13\x12\x1c\n\x18PRODUCT_EXTENSION_CLICKS\x10\x14\x12\x1d\n\x19PRODUCT_LISTING_AD_CLICKS\x10\x15\x12\r\n\tSITELINKS\x10\x16\x12\x11\n\rSTORE_LOCATOR\x10\x17\x12\x0e\n\nURL_CLICKS\x10\x19\x12\x1a\n\x16VIDEO_APP_STORE_CLICKS\x10\x1a\x12\x1f\n\x1bVIDEO_CALL_TO_ACTION_CLICKS\x10\x1b\x12%\n!VIDEO_CARD_ACTION_HEADLINE_CLICKS\x10\x1c\x12\x18\n\x14VIDEO_END_CAP_CLICKS\x10\x1d\x12\x18\n\x14VIDEO_WEBSITE_CLICKS\x10\x1e\x12\x14\n\x10VISUAL_SITELINKS\x10\x1f\x12\x11\n\rWIRELESS_PLAN\x10 \x12\x1c\n\x18PRODUCT_LISTING_AD_LOCAL\x10!\x12)\n%PRODUCT_LISTING_AD_MULTICHANNEL_LOCAL\x10\"\x12*\n&PRODUCT_LISTING_AD_MULTICHANNEL_ONLINE\x10#\x12\x1e\n\x1aPRODUCT_LISTING_ADS_COUPON\x10$\x12#\n\x1fPRODUCT_LISTING_AD_TRANSACTABLE\x10%\x12\x1b\n\x17PRODUCT_AD_APP_DEEPLINK\x10&\x12\x1d\n\x19SHOWCASE_AD_CATEGORY_LINK\x10\'\x12%\n!SHOWCASE_AD_LOCAL_STOREFRONT_LINK\x10(\x12#\n\x1fSHOWCASE_AD_ONLINE_PRODUCT_LINK\x10*\x12\"\n\x1eSHOWCASE_AD_LOCAL_PRODUCT_LINK\x10+\x12\x17\n\x13PROMOTION_EXTENSION\x10,\x12!\n\x1dSWIPEABLE_GALLERY_AD_HEADLINE\x10-\x12\x1f\n\x1bSWIPEABLE_GALLERY_AD_SWIPES\x10.\x12!\n\x1dSWIPEABLE_GALLERY_AD_SEE_MORE\x10/\x12%\n!SWIPEABLE_GALLERY_AD_SITELINK_ONE\x10\x30\x12%\n!SWIPEABLE_GALLERY_AD_SITELINK_TWO\x10\x31\x12\'\n#SWIPEABLE_GALLERY_AD_SITELINK_THREE\x10\x32\x12&\n\"SWIPEABLE_GALLERY_AD_SITELINK_FOUR\x10\x33\x12&\n\"SWIPEABLE_GALLERY_AD_SITELINK_FIVE\x10\x34\x12\x0f\n\x0bHOTEL_PRICE\x10\x35\x12\x13\n\x0fPRICE_EXTENSION\x10\x36\x12\'\n#HOTEL_BOOK_ON_GOOGLE_ROOM_SELECTION\x10\x37\x12\x1f\n\x1bSHOPPING_COMPARISON_LISTING\x10\x38\x42\xe3\x01\n!com.google.ads.googleads.v1.enumsB\x0e\x43lickTypeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CLICKTYPEENUM_CLICKTYPE = _descriptor.EnumDescriptor(
  name='ClickType',
  full_name='google.ads.googleads.v1.enums.ClickTypeEnum.ClickType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APP_DEEPLINK', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BREADCRUMBS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BROADBAND_PLAN', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALL_TRACKING', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLS', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLICK_ON_ENGAGEMENT_AD', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_DIRECTIONS', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_EXPANSION', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_FORMAT_CALL', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_FORMAT_DIRECTIONS', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_FORMAT_IMAGE', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_FORMAT_LANDING_PAGE', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_FORMAT_MAP', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_FORMAT_STORE_INFO', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_FORMAT_TEXT', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOBILE_CALL_TRACKING', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OFFER_PRINTS', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTHER', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT_EXTENSION_CLICKS', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT_LISTING_AD_CLICKS', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SITELINKS', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STORE_LOCATOR', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='URL_CLICKS', index=24, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_APP_STORE_CLICKS', index=25, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_CALL_TO_ACTION_CLICKS', index=26, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_CARD_ACTION_HEADLINE_CLICKS', index=27, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_END_CAP_CLICKS', index=28, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_WEBSITE_CLICKS', index=29, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VISUAL_SITELINKS', index=30, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WIRELESS_PLAN', index=31, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT_LISTING_AD_LOCAL', index=32, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT_LISTING_AD_MULTICHANNEL_LOCAL', index=33, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT_LISTING_AD_MULTICHANNEL_ONLINE', index=34, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT_LISTING_ADS_COUPON', index=35, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT_LISTING_AD_TRANSACTABLE', index=36, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT_AD_APP_DEEPLINK', index=37, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHOWCASE_AD_CATEGORY_LINK', index=38, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHOWCASE_AD_LOCAL_STOREFRONT_LINK', index=39, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHOWCASE_AD_ONLINE_PRODUCT_LINK', index=40, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHOWCASE_AD_LOCAL_PRODUCT_LINK', index=41, number=43,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMOTION_EXTENSION', index=42, number=44,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIPEABLE_GALLERY_AD_HEADLINE', index=43, number=45,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIPEABLE_GALLERY_AD_SWIPES', index=44, number=46,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIPEABLE_GALLERY_AD_SEE_MORE', index=45, number=47,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIPEABLE_GALLERY_AD_SITELINK_ONE', index=46, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIPEABLE_GALLERY_AD_SITELINK_TWO', index=47, number=49,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIPEABLE_GALLERY_AD_SITELINK_THREE', index=48, number=50,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIPEABLE_GALLERY_AD_SITELINK_FOUR', index=49, number=51,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWIPEABLE_GALLERY_AD_SITELINK_FIVE', index=50, number=52,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HOTEL_PRICE', index=51, number=53,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_EXTENSION', index=52, number=54,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HOTEL_BOOK_ON_GOOGLE_ROOM_SELECTION', index=53, number=55,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHOPPING_COMPARISON_LISTING', index=54, number=56,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=136,
  serialized_end=1692,
)
_sym_db.RegisterEnumDescriptor(_CLICKTYPEENUM_CLICKTYPE)


_CLICKTYPEENUM = _descriptor.Descriptor(
  name='ClickTypeEnum',
  full_name='google.ads.googleads.v1.enums.ClickTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLICKTYPEENUM_CLICKTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=1692,
)

_CLICKTYPEENUM_CLICKTYPE.containing_type = _CLICKTYPEENUM
DESCRIPTOR.message_types_by_name['ClickTypeEnum'] = _CLICKTYPEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClickTypeEnum = _reflection.GeneratedProtocolMessageType('ClickTypeEnum', (_message.Message,), dict(
  DESCRIPTOR = _CLICKTYPEENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.click_type_pb2'
  ,
  __doc__ = """Container for enumeration of Google Ads click types.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.ClickTypeEnum)
  ))
_sym_db.RegisterMessage(ClickTypeEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/criterion_type.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/criterion_type.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB\022CriterionTypeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\n8google/ads/googleads_v1/proto/enums/criterion_type.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\xd4\x04\n\x11\x43riterionTypeEnum\"\xbe\x04\n\rCriterionType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0b\n\x07KEYWORD\x10\x02\x12\r\n\tPLACEMENT\x10\x03\x12\x17\n\x13MOBILE_APP_CATEGORY\x10\x04\x12\x16\n\x12MOBILE_APPLICATION\x10\x05\x12\n\n\x06\x44\x45VICE\x10\x06\x12\x0c\n\x08LOCATION\x10\x07\x12\x11\n\rLISTING_GROUP\x10\x08\x12\x0f\n\x0b\x41\x44_SCHEDULE\x10\t\x12\r\n\tAGE_RANGE\x10\n\x12\n\n\x06GENDER\x10\x0b\x12\x10\n\x0cINCOME_RANGE\x10\x0c\x12\x13\n\x0fPARENTAL_STATUS\x10\r\x12\x11\n\rYOUTUBE_VIDEO\x10\x0e\x12\x13\n\x0fYOUTUBE_CHANNEL\x10\x0f\x12\r\n\tUSER_LIST\x10\x10\x12\r\n\tPROXIMITY\x10\x11\x12\t\n\x05TOPIC\x10\x12\x12\x11\n\rLISTING_SCOPE\x10\x13\x12\x0c\n\x08LANGUAGE\x10\x14\x12\x0c\n\x08IP_BLOCK\x10\x15\x12\x11\n\rCONTENT_LABEL\x10\x16\x12\x0b\n\x07\x43\x41RRIER\x10\x17\x12\x11\n\rUSER_INTEREST\x10\x18\x12\x0b\n\x07WEBPAGE\x10\x19\x12\x1c\n\x18OPERATING_SYSTEM_VERSION\x10\x1a\x12\x15\n\x11\x41PP_PAYMENT_MODEL\x10\x1b\x12\x11\n\rMOBILE_DEVICE\x10\x1c\x12\x13\n\x0f\x43USTOM_AFFINITY\x10\x1d\x12\x11\n\rCUSTOM_INTENT\x10\x1e\x12\x12\n\x0eLOCATION_GROUP\x10\x1f\x42\xe7\x01\n!com.google.ads.googleads.v1.enumsB\x12\x43riterionTypeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CRITERIONTYPEENUM_CRITERIONTYPE = _descriptor.EnumDescriptor(
  name='CriterionType',
  full_name='google.ads.googleads.v1.enums.CriterionTypeEnum.CriterionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEYWORD', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLACEMENT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOBILE_APP_CATEGORY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOBILE_APPLICATION', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_GROUP', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_SCHEDULE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GENDER', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOME_RANGE', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARENTAL_STATUS', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YOUTUBE_VIDEO', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YOUTUBE_CHANNEL', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_LIST', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROXIMITY', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOPIC', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_SCOPE', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANGUAGE', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IP_BLOCK', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTENT_LABEL', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARRIER', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_INTEREST', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBPAGE', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATING_SYSTEM_VERSION', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APP_PAYMENT_MODEL', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOBILE_DEVICE', index=28, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOM_AFFINITY', index=29, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOM_INTENT', index=30, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_GROUP', index=31, number=31,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=144,
  serialized_end=718,
)
_sym_db.RegisterEnumDescriptor(_CRITERIONTYPEENUM_CRITERIONTYPE)


_CRITERIONTYPEENUM = _descriptor.Descriptor(
  name='CriterionTypeEnum',
  full_name='google.ads.googleads.v1.enums.CriterionTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CRITERIONTYPEENUM_CRITERIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=718,
)

_CRITERIONTYPEENUM_CRITERIONTYPE.containing_type = _CRITERIONTYPEENUM
DESCRIPTOR.message_types_by_name['CriterionTypeEnum'] = _CRITERIONTYPEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CriterionTypeEnum = _reflection.GeneratedProtocolMessageType('CriterionTypeEnum', (_message.Message,), dict(
  DESCRIPTOR = _CRITERIONTYPEENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.criterion_type_pb2'
  ,
  __doc__ = """The possible types of a criterion.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.CriterionTypeEnum)
  ))
_sym_db.RegisterMessage(CriterionTypeEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/price_placeholder_field.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/price_placeholder_field.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB\032PricePlaceholderFieldProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\nAgoogle/ads/googleads_v1/proto/enums/price_placeholder_field.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\xef\t\n\x19PricePlaceholderFieldEnum\"\xd1\t\n\x15PricePlaceholderField\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x08\n\x04TYPE\x10\x02\x12\x13\n\x0fPRICE_QUALIFIER\x10\x03\x12\x15\n\x11TRACKING_TEMPLATE\x10\x04\x12\x0c\n\x08LANGUAGE\x10\x05\x12\x14\n\x10\x46INAL_URL_SUFFIX\x10\x06\x12\x11\n\rITEM_1_HEADER\x10\x64\x12\x16\n\x12ITEM_1_DESCRIPTION\x10\x65\x12\x10\n\x0cITEM_1_PRICE\x10\x66\x12\x0f\n\x0bITEM_1_UNIT\x10g\x12\x15\n\x11ITEM_1_FINAL_URLS\x10h\x12\x1c\n\x18ITEM_1_FINAL_MOBILE_URLS\x10i\x12\x12\n\rITEM_2_HEADER\x10\xc8\x01\x12\x17\n\x12ITEM_2_DESCRIPTION\x10\xc9\x01\x12\x11\n\x0cITEM_2_PRICE\x10\xca\x01\x12\x10\n\x0bITEM_2_UNIT\x10\xcb\x01\x12\x16\n\x11ITEM_2_FINAL_URLS\x10\xcc\x01\x12\x1d\n\x18ITEM_2_FINAL_MOBILE_URLS\x10\xcd\x01\x12\x12\n\rITEM_3_HEADER\x10\xac\x02\x12\x17\n\x12ITEM_3_DESCRIPTION\x10\xad\x02\x12\x11\n\x0cITEM_3_PRICE\x10\xae\x02\x12\x10\n\x0bITEM_3_UNIT\x10\xaf\x02\x12\x16\n\x11ITEM_3_FINAL_URLS\x10\xb0\x02\x12\x1d\n\x18ITEM_3_FINAL_MOBILE_URLS\x10\xb1\x02\x12\x12\n\rITEM_4_HEADER\x10\x90\x03\x12\x17\n\x12ITEM_4_DESCRIPTION\x10\x91\x03\x12\x11\n\x0cITEM_4_PRICE\x10\x92\x03\x12\x10\n\x0bITEM_4_UNIT\x10\x93\x03\x12\x16\n\x11ITEM_4_FINAL_URLS\x10\x94\x03\x12\x1d\n\x18ITEM_4_FINAL_MOBILE_URLS\x10\x95\x03\x12\x12\n\rITEM_5_HEADER\x10\xf4\x03\x12\x17\n\x12ITEM_5_DESCRIPTION\x10\xf5\x03\x12\x11\n\x0cITEM_5_PRICE\x10\xf6\x03\x12\x10\n\x0bITEM_5_UNIT\x10\xf7\x03\x12\x16\n\x11ITEM_5_FINAL_URLS\x10\xf8\x03\x12\x1d\n\x18ITEM_5_FINAL_MOBILE_URLS\x10\xf9\x03\x12\x12\n\rITEM_6_HEADER\x10\xd8\x04\x12\x17\n\x12ITEM_6_DESCRIPTION\x10\xd9\x04\x12\x11\n\x0cITEM_6_PRICE\x10\xda\x04\x12\x10\n\x0bITEM_6_UNIT\x10\xdb\x04\x12\x16\n\x11ITEM_6_FINAL_URLS\x10\xdc\x04\x12\x1d\n\x18ITEM_6_FINAL_MOBILE_URLS\x10\xdd\x04\x12\x12\n\rITEM_7_HEADER\x10\xbc\x05\x12\x17\n\x12ITEM_7_DESCRIPTION\x10\xbd\x05\x12\x11\n\x0cITEM_7_PRICE\x10\xbe\x05\x12\x10\n\x0bITEM_7_UNIT\x10\xbf\x05\x12\x16\n\x11ITEM_7_FINAL_URLS\x10\xc0\x05\x12\x1d\n\x18ITEM_7_FINAL_MOBILE_URLS\x10\xc1\x05\x12\x12\n\rITEM_8_HEADER\x10\xa0\x06\x12\x17\n\x12ITEM_8_DESCRIPTION\x10\xa1\x06\x12\x11\n\x0cITEM_8_PRICE\x10\xa2\x06\x12\x10\n\x0bITEM_8_UNIT\x10\xa3\x06\x12\x16\n\x11ITEM_8_FINAL_URLS\x10\xa4\x06\x12\x1d\n\x18ITEM_8_FINAL_MOBILE_URLS\x10\xa5\x06\x42\xef\x01\n!com.google.ads.googleads.v1.enumsB\x1aPricePlaceholderFieldProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_PRICEPLACEHOLDERFIELDENUM_PRICEPLACEHOLDERFIELD = _descriptor.EnumDescriptor(
  name='PricePlaceholderField',
  full_name='google.ads.googleads.v1.enums.PricePlaceholderFieldEnum.PricePlaceholderField',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TYPE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_QUALIFIER', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRACKING_TEMPLATE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANGUAGE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_URL_SUFFIX', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_1_HEADER', index=7, number=100,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_1_DESCRIPTION', index=8, number=101,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_1_PRICE', index=9, number=102,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_1_UNIT', index=10, number=103,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_1_FINAL_URLS', index=11, number=104,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_1_FINAL_MOBILE_URLS', index=12, number=105,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_2_HEADER', index=13, number=200,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_2_DESCRIPTION', index=14, number=201,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_2_PRICE', index=15, number=202,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_2_UNIT', index=16, number=203,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_2_FINAL_URLS', index=17, number=204,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_2_FINAL_MOBILE_URLS', index=18, number=205,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_3_HEADER', index=19, number=300,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_3_DESCRIPTION', index=20, number=301,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_3_PRICE', index=21, number=302,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_3_UNIT', index=22, number=303,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_3_FINAL_URLS', index=23, number=304,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_3_FINAL_MOBILE_URLS', index=24, number=305,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_4_HEADER', index=25, number=400,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_4_DESCRIPTION', index=26, number=401,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_4_PRICE', index=27, number=402,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_4_UNIT', index=28, number=403,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_4_FINAL_URLS', index=29, number=404,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_4_FINAL_MOBILE_URLS', index=30, number=405,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_5_HEADER', index=31, number=500,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_5_DESCRIPTION', index=32, number=501,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_5_PRICE', index=33, number=502,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_5_UNIT', index=34, number=503,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_5_FINAL_URLS', index=35, number=504,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_5_FINAL_MOBILE_URLS', index=36, number=505,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_6_HEADER', index=37, number=600,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_6_DESCRIPTION', index=38, number=601,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_6_PRICE', index=39, number=602,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_6_UNIT', index=40, number=603,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_6_FINAL_URLS', index=41, number=604,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_6_FINAL_MOBILE_URLS', index=42, number=605,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_7_HEADER', index=43, number=700,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_7_DESCRIPTION', index=44, number=701,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_7_PRICE', index=45, number=702,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_7_UNIT', index=46, number=703,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_7_FINAL_URLS', index=47, number=704,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_7_FINAL_MOBILE_URLS', index=48, number=705,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_8_HEADER', index=49, number=800,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_8_DESCRIPTION', index=50, number=801,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_8_PRICE', index=51, number=802,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_8_UNIT', index=52, number=803,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_8_FINAL_URLS', index=53, number=804,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_8_FINAL_MOBILE_URLS', index=54, number=805,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=161,
  serialized_end=1394,
)
_sym_db.RegisterEnumDescriptor(_PRICEPLACEHOLDERFIELDENUM_PRICEPLACEHOLDERFIELD)


_PRICEPLACEHOLDERFIELDENUM = _descriptor.Descriptor(
  name='PricePlaceholderFieldEnum',
  full_name='google.ads.googleads.v1.enums.PricePlaceholderFieldEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PRICEPLACEHOLDERFIELDENUM_PRICEPLACEHOLDERFIELD,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=1394,
)

_PRICEPLACEHOLDERFIELDENUM_PRICEPLACEHOLDERFIELD.containing_type = _PRICEPLACEHOLDERFIELDENUM
DESCRIPTOR.message_types_by_name['PricePlaceholderFieldEnum'] = _PRICEPLACEHOLDERFIELDENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PricePlaceholderFieldEnum = _reflection.GeneratedProtocolMessageType('PricePlaceholderFieldEnum', (_message.Message,), dict(
  DESCRIPTOR = _PRICEPLACEHOLDERFIELDENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.price_placeholder_field_pb2'
  ,
  __doc__ = """Values for Price placeholder fields.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.PricePlaceholderFieldEnum)
  ))
_sym_db.RegisterMessage(PricePlaceholderFieldEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/keyword_plan_campaign.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import keyword_plan_network_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_keyword__plan__network__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/keyword_plan_campaign.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\030KeywordPlanCampaignProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\nCgoogle/ads/googleads_v2/proto/resources/keyword_plan_campaign.proto\x12!google.ads.googleads.v2.resources\x1a>google/ads/googleads_v2/proto/enums/keyword_plan_network.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xda\x03\n\x13KeywordPlanCampaign\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x32\n\x0ckeyword_plan\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x12language_constants\x18\x05 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x66\n\x14keyword_plan_network\x18\x06 \x01(\x0e\x32H.google.ads.googleads.v2.enums.KeywordPlanNetworkEnum.KeywordPlanNetwork\x12\x33\n\x0e\x63pc_bid_micros\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\x0bgeo_targets\x18\x08 \x03(\x0b\x32\x37.google.ads.googleads.v2.resources.KeywordPlanGeoTarget\"Q\n\x14KeywordPlanGeoTarget\x12\x39\n\x13geo_target_constant\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x85\x02\n%com.google.ads.googleads.v2.resourcesB\x18KeywordPlanCampaignProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_keyword__plan__network__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_KEYWORDPLANCAMPAIGN = _descriptor.Descriptor(
  name='KeywordPlanCampaign',
  full_name='google.ads.googleads.v2.resources.KeywordPlanCampaign',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.KeywordPlanCampaign.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan', full_name='google.ads.googleads.v2.resources.KeywordPlanCampaign.keyword_plan', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.KeywordPlanCampaign.id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.resources.KeywordPlanCampaign.name', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language_constants', full_name='google.ads.googleads.v2.resources.KeywordPlanCampaign.language_constants', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_network', full_name='google.ads.googleads.v2.resources.KeywordPlanCampaign.keyword_plan_network', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpc_bid_micros', full_name='google.ads.googleads.v2.resources.KeywordPlanCampaign.cpc_bid_micros', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_targets', full_name='google.ads.googleads.v2.resources.KeywordPlanCampaign.geo_targets', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=707,
)


_KEYWORDPLANGEOTARGET = _descriptor.Descriptor(
  name='KeywordPlanGeoTarget',
  full_name='google.ads.googleads.v2.resources.KeywordPlanGeoTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='geo_target_constant', full_name='google.ads.googleads.v2.resources.KeywordPlanGeoTarget.geo_target_constant', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=709,
  serialized_end=790,
)

_KEYWORDPLANCAMPAIGN.fields_by_name['keyword_plan'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLANCAMPAIGN.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_KEYWORDPLANCAMPAIGN.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLANCAMPAIGN.fields_by_name['language_constants'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLANCAMPAIGN.fields_by_name['keyword_plan_network'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_keyword__plan__network__pb2._KEYWORDPLANNETWORKENUM_KEYWORDPLANNETWORK
_KEYWORDPLANCAMPAIGN.fields_by_name['cpc_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_KEYWORDPLANCAMPAIGN.fields_by_name['geo_targets'].message_type = _KEYWORDPLANGEOTARGET
_KEYWORDPLANGEOTARGET.fields_by_name['geo_target_constant'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['KeywordPlanCampaign'] = _KEYWORDPLANCAMPAIGN
DESCRIPTOR.message_types_by_name['KeywordPlanGeoTarget'] = _KEYWORDPLANGEOTARGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeywordPlanCampaign = _reflection.GeneratedProtocolMessageType('KeywordPlanCampaign', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANCAMPAIGN,
  __module__ = 'google.ads.googleads_v2.proto.resources.keyword_plan_campaign_pb2'
  ,
  __doc__ = """A Keyword Plan campaign. Max number of keyword plan campaigns per plan
  allowed: 1.
  
  
  Attributes:
      resource_name:
          The resource name of the Keyword Plan campaign.
          KeywordPlanCampaign resource names have the form:  ``customers
          /{customer_id}/keywordPlanCampaigns/{kp_campaign_id}``
      keyword_plan:
          The keyword plan this campaign belongs to.
      id:
          The ID of the Keyword Plan campaign.
      name:
          The name of the Keyword Plan campaign.  This field is required
          and should not be empty when creating Keyword Plan campaigns.
      language_constants:
          The languages targeted for the Keyword Plan campaign. Max
          allowed: 1.
      keyword_plan_network:
          Targeting network.  This field is required and should not be
          empty when creating Keyword Plan campaigns.
      cpc_bid_micros:
          A default max cpc bid in micros, and in the account currency,
          for all ad groups under the campaign.  This field is required
          and should not be empty when creating Keyword Plan campaigns.
      geo_targets:
          The geo targets. Max number allowed: 20.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.KeywordPlanCampaign)
  ))
_sym_db.RegisterMessage(KeywordPlanCampaign)

KeywordPlanGeoTarget = _reflection.GeneratedProtocolMessageType('KeywordPlanGeoTarget', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANGEOTARGET,
  __module__ = 'google.ads.googleads_v2.proto.resources.keyword_plan_campaign_pb2'
  ,
  __doc__ = """A geo target. Next ID: 3
  
  
  Attributes:
      geo_target_constant:
          Required. The resource name of the geo target.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.KeywordPlanGeoTarget)
  ))
_sym_db.RegisterMessage(KeywordPlanGeoTarget)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
